diff mcabber/src/settings.c @ 1068:6646d2ed7f74

Allow pgp commands in config file, update sample configuration file
author Mikael Berthe <mikael@lilotux.net>
date Sat, 02 Dec 2006 13:29:56 +0100
parents 230dca34dbea
children 9eaacc0ad3a2
line wrap: on
line diff
--- a/mcabber/src/settings.c	Sat Dec 02 13:11:44 2006 +0100
+++ b/mcabber/src/settings.c	Sat Dec 02 13:29:56 2006 +0100
@@ -149,9 +149,10 @@
     if ((*line == '\n') || (*line == '\0') || (*line == '#'))
       continue;
 
-    if ((strchr(line, '=') != NULL)) {
-      // Only accept the set, alias and bind commands
+    if ((strchr(line, '=') != NULL) || !strncmp(line, "pgp ", strlen("pgp "))) {
+      // Only accept the set, alias, bind and pgp commands
       if (strncmp(line, "set ", strlen("set ")) &&
+          strncmp(line, "pgp ", strlen("pgp ")) &&
           strncmp(line, "bind ", strlen("bind ")) &&
           strncmp(line, "alias ", strlen("alias "))) {
         scr_LogPrint(LPRINT_LOGNORM,